==> collective.prettyphoto-0.1.tar.gz: collective.prettyphoto-0.1/collective/prettyphoto/exportimport.py <==
from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.interfaces import IPropertiesTool

# Properties are defined here, because if they are defined in
# propertiestool.xml, all properties are re-set the their initial state if you
# reinstall product in the quickinstaller.

_PROPERTIES = [
    dict(name='speed', type_='string', value='normal'),
    dict(name='opacity', type_='string', value='0.80'),
    dict(name='show_title', type_='boolean', value=True),
    dict(name='counter_sep', type_='string', value='/'),
    dict(name='theme', type_='string', value='light_rounded'),
    dict(name='autoplay', type_='boolean', value=True),
    dict(name='iframe_width', type_='string', value='75%'),
    dict(name='iframe_height', type_='string', value='75%'),
]


def import_various(context):
    if not context.readDataFile('collective.prettyphoto.txt'):
        return

    site = context.getSite()
    kupu = getToolByName(site, 'kupu_library_tool')

    paragraph_styles = list(kupu.getParagraphStyles())

    new_styles = [('prettyPhoto', 'prettyPhoto|a'), ]
    to_add = dict(new_styles)

    for style in paragraph_styles:
        css_class = style.split('|')[-1]
        if css_class in to_add:
            del to_add[css_class]

    if to_add:
        paragraph_styles += ['%s|%s' % (v, k) for k, v in new_styles if \
                             k in to_add]
        kupu.configure_kupu(parastyles=paragraph_styles)

    # Define portal properties
    ptool = getToolByName(site, 'portal_properties')
    props = ptool.prettyphoto_properties

    for prop in _PROPERTIES:
        if not props.hasProperty(prop['name']):
            props.manage_addProperty(prop['name'], prop['value'],
                                     prop['type_'])

==> collective.prettyphoto-0.2.tar.gz: collective.prettyphoto-0.2/collective/prettyphoto/exportimport.py <==
from Products.CMFCore.utils import getToolByName
from Products.CMFPlone.interfaces import IPropertiesTool

# Properties are defined here, because if they are defined in
# propertiestool.xml, all properties are re-set the their initial state if you
# reinstall product in the quickinstaller.

_PROPERTIES = [
    dict(name='speed', type_='string', value='normal'),
    dict(name='opacity', type_='string', value='0.80'),
    dict(name='show_title', type_='boolean', value=True),
    dict(name='counter_sep', type_='string', value='/'),
    dict(name='theme', type_='string', value='light_rounded'),
    dict(name='autoplay', type_='boolean', value=True),
    dict(name='iframe_width', type_='string', value='75%'),
    dict(name='iframe_height', type_='string', value='75%'),
]


def import_various(context):
    if not context.readDataFile('collective.prettyphoto.txt'):
        return

    site = context.getSite()
    kupu = getToolByName(site, 'kupu_library_tool')

    paragraph_styles = list(kupu.getParagraphStyles())

    new_styles = [
        ('prettyPhoto', 'prettyPhoto Link|a'),
        ('prettyPhotoIframe', 'prettyPhoto Iframe Link|a'),
    ]
    to_add = dict(new_styles)

    for style in paragraph_styles:
        css_class = style.split('|')[-1]
        if css_class in to_add:
            del to_add[css_class]

    if to_add:
        paragraph_styles += ['%s|%s' % (v, k) for k, v in new_styles if \
                             k in to_add]
        kupu.configure_kupu(parastyles=paragraph_styles)

    # Define portal properties
    ptool = getToolByName(site, 'portal_properties')
    props = ptool.prettyphoto_properties

    for prop in _PROPERTIES:
        if not props.hasProperty(prop['name']):
            props.manage_addProperty(prop['name'], prop['value'],
                                     prop['type_'])
